# musictool

### install
```sh
pip install musictool
```

### or install the latest version from github
```sh
pip install git+https://github.com/tandav/musictool
```

### development
```sh
pip install -e .[dev]
```
